============================================
``psyclone.tests.dynamo0p3_quadrature_test``
============================================

.. automodule:: psyclone.tests.dynamo0p3_quadrature_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.dynamo0p3_quadrature_test
